@@ -37,8 +37,8 @@ import Data.Text (Text)
 import Data.Text.Encoding (decodeUtf8With)
 import Data.Text.Encoding.Error (lenientDecode)
 
-import Database.Persist (PersistField)
-import Database.Persist.Sql (PersistFieldSql)
+import Database.Persist (PersistField, SqlType(SqlString))
+import Database.Persist.Sql (PersistFieldSql(..))
 import System.Directory (doesFileExist)
 
 import Text.Blaze (ToMarkup (toMarkup))
@@ -56,7 +56,10 @@ import qualified Data.ByteString as B
 import qualified Data.Text       as T
 
 newtype Markdown = Markdown { unMarkdown :: Text }
-    deriving (Eq, Ord, Show, Read, PersistField, PersistFieldSql, IsString, Monoid)
+    deriving (Eq, Ord, Show, Read, PersistField, IsString, Monoid)
+
+instance PersistFieldSql Markdown where
+    sqlType _ = SqlString
 
 instance ToMarkup Markdown where
     -- | Sanitized by default
@@ -110,8 +113,9 @@ parseMarkdown ro = readMarkdown ro . T.unpack . unMarkdown
 -- | Defaults plus Html5, minus WrapText
 yesodDefaultWriterOptions :: WriterOptions
 yesodDefaultWriterOptions = def
-  { writerHtml5    = True
-  , writerWrapText = False
+  { writerHtml5     = True
+  , writerWrapText  = False
+  , writerHighlight = True
   }
 
 -- | Defaults plus Smart and ParseRaw
